@@ -1,3 +1,9 @@
+try:
+    # noinspection PyShadowingBuiltins
+    from printlog import printlog as print
+except ImportError:
+    pass
+
 try:
     import gpio_cmds
     print("Running on robot...")
@@ -6,6 +12,7 @@ except ImportError:
     print("Running in emulation mode...")
     emulate = True
 
+
 target_drive_speed = 75
 
 def forward():
